@@ -2,9 +2,11 @@
 # @brief Adds geostatistical methods into Geo::Raster
 package Geo::Raster;
 
-## @method array variogram(max_lag, lags)
+use strict;
+
+## @method array variogram($max_lag, $lags)
 #
-# @brief Computes the variogram from the grid
+# @brief Computes a variogram from the raster.
 # @param[in] max_lag maximum distance to which the variogram is computed
 # @param[in] lags the number of ranges of h used in computing the variogram
 # @return a list of lists (h, y(h))
