@@ -3,6 +3,7 @@
 package Geo::Raster;
 
 use strict;
+use Scalar::Util 'blessed';
 
 ## @method Geo::Raster frame($with)
 #
@@ -77,7 +78,7 @@ sub line {
 sub transect {
     my($self, $geom, $delta) = @_;
     croak "usage: \$raster->transect(\$geometry, \$delta)" 
-	unless $geom->isa('Geo::OGR::Geometry') and (defined $delta and $delta > 0);
+	unless blessed($geom) and $geom->isa('Geo::OGR::Geometry') and (defined $delta and $delta > 0);
     my @transect;
     if ($geom->GetGeometryCount) {
 	for (0..$geom->GetGeometryCount-1) {
